import { API as ParentAPI } from '../../../bridge';
import type { WaitForOptions } from '../../../bridge';
import type { BackendStage, CacheStage, CheckDomainRequest, CheckDomainResponse, CheckLbOriginRequest, CheckLbOriginResponse, CheckPEMChainRequest, CheckPEMChainResponse, CreateBackendStageRequest, CreateCacheStageRequest, CreateDNSStageRequest, CreatePipelineRequest, CreatePurgeRequestRequest, CreateTLSStageRequest, DNSStage, DeleteBackendStageRequest, DeleteCacheStageRequest, DeleteCurrentPlanRequest, DeleteDNSStageRequest, DeletePipelineRequest, DeleteTLSStageRequest, GetBackendStageRequest, GetBillingRequest, GetBillingResponse, GetCacheStageRequest, GetCurrentPlanRequest, GetDNSStageRequest, GetPipelineRequest, GetPurgeRequestRequest, GetTLSStageRequest, ListBackendStagesRequest, ListBackendStagesResponse, ListCacheStagesRequest, ListCacheStagesResponse, ListDNSStagesRequest, ListDNSStagesResponse, ListPipelinesRequest, ListPipelinesResponse, ListPipelinesWithStagesRequest, ListPipelinesWithStagesResponse, ListPlansResponse, ListPurgeRequestsRequest, ListPurgeRequestsResponse, ListTLSStagesRequest, ListTLSStagesResponse, Pipeline, Plan, PurgeRequest, SelectPlanRequest, TLSStage, UpdateBackendStageRequest, UpdateCacheStageRequest, UpdateDNSStageRequest, UpdatePipelineRequest, UpdateTLSStageRequest } from './types.gen';
/** Edge Services API. */
export declare class API extends ParentAPI {
    protected pageOfListPipelines: (request?: Readonly<ListPipelinesRequest>) => Promise<ListPipelinesResponse>;
    /**
     * List pipelines. List all pipelines, for a Scaleway Organization or Scaleway
     * Project. By default, the pipelines returned in the list are ordered by
     * creation date in ascending order, though this can be modified via the
     * `order_by` field.
     *
     * @param request - The request {@link ListPipelinesRequest}
     * @returns A Promise of ListPipelinesResponse
     */
    listPipelines: (request?: Readonly<ListPipelinesRequest>) => Promise<ListPipelinesResponse> & {
        all: () => Promise<Pipeline[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Pipeline[], void, void>;
    };
    /**
     * Create pipeline. Create a new pipeline. You must specify a `dns_stage_id`
     * to form a stage-chain that goes all the way to the backend stage (origin),
     * so the HTTP request will be processed according to the stages you created.
     *
     * @param request - The request {@link CreatePipelineRequest}
     * @returns A Promise of Pipeline
     */
    createPipeline: (request: Readonly<CreatePipelineRequest>) => Promise<Pipeline>;
    /**
     * Get pipeline. Retrieve information about an existing pipeline, specified by
     * its `pipeline_id`. Its full details, including errors, are returned in the
     * response object.
     *
     * @param request - The request {@link GetPipelineRequest}
     * @returns A Promise of Pipeline
     */
    getPipeline: (request: Readonly<GetPipelineRequest>) => Promise<Pipeline>;
    /**
     * Waits for {@link Pipeline} to be in a final state.
     *
     * @param request - The request {@link GetPipelineRequest}
     * @param options - The waiting options
     * @returns A Promise of Pipeline
     */
    waitForPipeline: (request: Readonly<GetPipelineRequest>, options?: Readonly<WaitForOptions<Pipeline>>) => Promise<Pipeline>;
    protected pageOfListPipelinesWithStages: (request?: Readonly<ListPipelinesWithStagesRequest>) => Promise<ListPipelinesWithStagesResponse>;
    listPipelinesWithStages: (request?: Readonly<ListPipelinesWithStagesRequest>) => Promise<ListPipelinesWithStagesResponse> & {
        all: () => Promise<import("./types.gen").PipelineStages[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").PipelineStages[], void, void>;
    };
    /**
     * Update pipeline. Update the parameters of an existing pipeline, specified
     * by its `pipeline_id`. Parameters which can be updated include the `name`,
     * `description` and `dns_stage_id`.
     *
     * @param request - The request {@link UpdatePipelineRequest}
     * @returns A Promise of Pipeline
     */
    updatePipeline: (request: Readonly<UpdatePipelineRequest>) => Promise<Pipeline>;
    /**
     * Delete pipeline. Delete an existing pipeline, specified by its
     * `pipeline_id`. Deleting a pipeline is permanent, and cannot be undone. Note
     * that all stages linked to the pipeline are also deleted.
     *
     * @param request - The request {@link DeletePipelineRequest}
     */
    deletePipeline: (request: Readonly<DeletePipelineRequest>) => Promise<void>;
    protected pageOfListDNSStages: (request?: Readonly<ListDNSStagesRequest>) => Promise<ListDNSStagesResponse>;
    /**
     * List DNS stages. List all DNS stages, for a Scaleway Organization or
     * Scaleway Project. By default, the DNS stages returned in the list are
     * ordered by creation date in ascending order, though this can be modified
     * via the `order_by` field.
     *
     * @param request - The request {@link ListDNSStagesRequest}
     * @returns A Promise of ListDNSStagesResponse
     */
    listDNSStages: (request?: Readonly<ListDNSStagesRequest>) => Promise<ListDNSStagesResponse> & {
        all: () => Promise<DNSStage[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<DNSStage[], void, void>;
    };
    /**
     * Create DNS stage. Create a new DNS stage. You must specify the `fqdns`
     * field to customize the domain endpoint, using a domain you already own.
     *
     * @param request - The request {@link CreateDNSStageRequest}
     * @returns A Promise of DNSStage
     */
    createDNSStage: (request?: Readonly<CreateDNSStageRequest>) => Promise<DNSStage>;
    /**
     * Get DNS stage. Retrieve information about an existing DNS stage, specified
     * by its `dns_stage_id`. Its full details, including FQDNs, are returned in
     * the response object.
     *
     * @param request - The request {@link GetDNSStageRequest}
     * @returns A Promise of DNSStage
     */
    getDNSStage: (request: Readonly<GetDNSStageRequest>) => Promise<DNSStage>;
    /**
     * Update DNS stage. Update the parameters of an existing DNS stage, specified
     * by its `dns_stage_id`.
     *
     * @param request - The request {@link UpdateDNSStageRequest}
     * @returns A Promise of DNSStage
     */
    updateDNSStage: (request: Readonly<UpdateDNSStageRequest>) => Promise<DNSStage>;
    /**
     * Delete DNS stage. Delete an existing DNS stage, specified by its
     * `dns_stage_id`. Deleting a DNS stage is permanent, and cannot be undone.
     *
     * @param request - The request {@link DeleteDNSStageRequest}
     */
    deleteDNSStage: (request: Readonly<DeleteDNSStageRequest>) => Promise<void>;
    protected pageOfListTLSStages: (request?: Readonly<ListTLSStagesRequest>) => Promise<ListTLSStagesResponse>;
    /**
     * List TLS stages. List all TLS stages, for a Scaleway Organization or
     * Scaleway Project. By default, the TLS stages returned in the list are
     * ordered by creation date in ascending order, though this can be modified
     * via the `order_by` field.
     *
     * @param request - The request {@link ListTLSStagesRequest}
     * @returns A Promise of ListTLSStagesResponse
     */
    listTLSStages: (request?: Readonly<ListTLSStagesRequest>) => Promise<ListTLSStagesResponse> & {
        all: () => Promise<TLSStage[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<TLSStage[], void, void>;
    };
    /**
     * Create TLS stage. Create a new TLS stage. You must specify either the
     * `secrets` or `managed_certificate` fields to customize the SSL/TLS
     * certificate of your endpoint. Choose `secrets` if you are using a
     * pre-existing certificate held in Scaleway Secret Manager, or
     * `managed_certificate` to let Scaleway generate and manage a Let's Encrypt
     * certificate for your customized endpoint.
     *
     * @param request - The request {@link CreateTLSStageRequest}
     * @returns A Promise of TLSStage
     */
    createTLSStage: (request?: Readonly<CreateTLSStageRequest>) => Promise<TLSStage>;
    /**
     * Get TLS stage. Retrieve information about an existing TLS stage, specified
     * by its `tls_stage_id`. Its full details, including secrets and certificate
     * expiration date are returned in the response object.
     *
     * @param request - The request {@link GetTLSStageRequest}
     * @returns A Promise of TLSStage
     */
    getTLSStage: (request: Readonly<GetTLSStageRequest>) => Promise<TLSStage>;
    /**
     * Update TLS stage. Update the parameters of an existing TLS stage, specified
     * by its `tls_stage_id`. Both `tls_secrets_config` and `managed_certificate`
     * parameters can be updated.
     *
     * @param request - The request {@link UpdateTLSStageRequest}
     * @returns A Promise of TLSStage
     */
    updateTLSStage: (request: Readonly<UpdateTLSStageRequest>) => Promise<TLSStage>;
    /**
     * Delete TLS stage. Delete an existing TLS stage, specified by its
     * `tls_stage_id`. Deleting a TLS stage is permanent, and cannot be undone.
     *
     * @param request - The request {@link DeleteTLSStageRequest}
     */
    deleteTLSStage: (request: Readonly<DeleteTLSStageRequest>) => Promise<void>;
    protected pageOfListCacheStages: (request?: Readonly<ListCacheStagesRequest>) => Promise<ListCacheStagesResponse>;
    /**
     * List cache stages. List all cache stages, for a Scaleway Organization or
     * Scaleway Project. By default, the cache stages returned in the list are
     * ordered by creation date in ascending order, though this can be modified
     * via the `order_by` field.
     *
     * @param request - The request {@link ListCacheStagesRequest}
     * @returns A Promise of ListCacheStagesResponse
     */
    listCacheStages: (request?: Readonly<ListCacheStagesRequest>) => Promise<ListCacheStagesResponse> & {
        all: () => Promise<CacheStage[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<CacheStage[], void, void>;
    };
    /**
     * Create cache stage. Create a new cache stage. You must specify the
     * `fallback_ttl` field to customize the TTL of the cache.
     *
     * @param request - The request {@link CreateCacheStageRequest}
     * @returns A Promise of CacheStage
     */
    createCacheStage: (request?: Readonly<CreateCacheStageRequest>) => Promise<CacheStage>;
    /**
     * Get cache stage. Retrieve information about an existing cache stage,
     * specified by its `cache_stage_id`. Its full details, including Time To Live
     * (TTL), are returned in the response object.
     *
     * @param request - The request {@link GetCacheStageRequest}
     * @returns A Promise of CacheStage
     */
    getCacheStage: (request: Readonly<GetCacheStageRequest>) => Promise<CacheStage>;
    /**
     * Update cache stage. Update the parameters of an existing cache stage,
     * specified by its `cache_stage_id`. Parameters which can be updated include
     * the `fallback_ttl` and `backend_stage_id`.
     *
     * @param request - The request {@link UpdateCacheStageRequest}
     * @returns A Promise of CacheStage
     */
    updateCacheStage: (request: Readonly<UpdateCacheStageRequest>) => Promise<CacheStage>;
    /**
     * Delete cache stage. Delete an existing cache stage, specified by its
     * `cache_stage_id`. Deleting a cache stage is permanent, and cannot be
     * undone.
     *
     * @param request - The request {@link DeleteCacheStageRequest}
     */
    deleteCacheStage: (request: Readonly<DeleteCacheStageRequest>) => Promise<void>;
    protected pageOfListBackendStages: (request?: Readonly<ListBackendStagesRequest>) => Promise<ListBackendStagesResponse>;
    /**
     * List backend stages. List all backend stages, for a Scaleway Organization
     * or Scaleway Project. By default, the backend stages returned in the list
     * are ordered by creation date in ascending order, though this can be
     * modified via the `order_by` field.
     *
     * @param request - The request {@link ListBackendStagesRequest}
     * @returns A Promise of ListBackendStagesResponse
     */
    listBackendStages: (request?: Readonly<ListBackendStagesRequest>) => Promise<ListBackendStagesResponse> & {
        all: () => Promise<BackendStage[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<BackendStage[], void, void>;
    };
    /**
     * Create backend stage. Create a new backend stage. You must specify either a
     * `scaleway_s3` (for a Scaleway Object Storage bucket) or `scaleway_lb` (for
     * a Scaleway Load Balancer) field to configure the origin.
     *
     * @param request - The request {@link CreateBackendStageRequest}
     * @returns A Promise of BackendStage
     */
    createBackendStage: (request?: Readonly<CreateBackendStageRequest>) => Promise<BackendStage>;
    /**
     * Get backend stage. Retrieve information about an existing backend stage,
     * specified by its `backend_stage_id`. Its full details, including
     * `scaleway_s3` or `scaleway_lb`, are returned in the response object.
     *
     * @param request - The request {@link GetBackendStageRequest}
     * @returns A Promise of BackendStage
     */
    getBackendStage: (request: Readonly<GetBackendStageRequest>) => Promise<BackendStage>;
    /**
     * Update backend stage. Update the parameters of an existing backend stage,
     * specified by its `backend_stage_id`.
     *
     * @param request - The request {@link UpdateBackendStageRequest}
     * @returns A Promise of BackendStage
     */
    updateBackendStage: (request: Readonly<UpdateBackendStageRequest>) => Promise<BackendStage>;
    /**
     * Delete backend stage. Delete an existing backend stage, specified by its
     * `backend_stage_id`. Deleting a backend stage is permanent, and cannot be
     * undone.
     *
     * @param request - The request {@link DeleteBackendStageRequest}
     */
    deleteBackendStage: (request: Readonly<DeleteBackendStageRequest>) => Promise<void>;
    checkDomain: (request: Readonly<CheckDomainRequest>) => Promise<CheckDomainResponse>;
    checkPEMChain: (request: Readonly<CheckPEMChainRequest>) => Promise<CheckPEMChainResponse>;
    protected pageOfListPurgeRequests: (request?: Readonly<ListPurgeRequestsRequest>) => Promise<ListPurgeRequestsResponse>;
    /**
     * List purge requests. List all purge requests, for a Scaleway Organization
     * or Scaleway Project. This enables you to retrieve a history of all
     * previously-made purge requests. By default, the purge requests returned in
     * the list are ordered by creation date in ascending order, though this can
     * be modified via the `order_by` field.
     *
     * @param request - The request {@link ListPurgeRequestsRequest}
     * @returns A Promise of ListPurgeRequestsResponse
     */
    listPurgeRequests: (request?: Readonly<ListPurgeRequestsRequest>) => Promise<ListPurgeRequestsResponse> & {
        all: () => Promise<PurgeRequest[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<PurgeRequest[], void, void>;
    };
    /**
     * Create purge request. Create a new purge request. You must specify either
     * the `all` field (to purge all content) or a list of `assets` (to define the
     * precise assets to purge).
     *
     * @param request - The request {@link CreatePurgeRequestRequest}
     * @returns A Promise of PurgeRequest
     */
    createPurgeRequest: (request: Readonly<CreatePurgeRequestRequest>) => Promise<PurgeRequest>;
    /**
     * Get purge request. Retrieve information about a purge request, specified by
     * its `purge_request_id`. Its full details, including `status` and `target`,
     * are returned in the response object.
     *
     * @param request - The request {@link GetPurgeRequestRequest}
     * @returns A Promise of PurgeRequest
     */
    getPurgeRequest: (request: Readonly<GetPurgeRequestRequest>) => Promise<PurgeRequest>;
    /**
     * Waits for {@link PurgeRequest} to be in a final state.
     *
     * @param request - The request {@link GetPurgeRequestRequest}
     * @param options - The waiting options
     * @returns A Promise of PurgeRequest
     */
    waitForPurgeRequest: (request: Readonly<GetPurgeRequestRequest>, options?: Readonly<WaitForOptions<PurgeRequest>>) => Promise<PurgeRequest>;
    checkLbOrigin: (request?: Readonly<CheckLbOriginRequest>) => Promise<CheckLbOriginResponse>;
    listPlans: () => Promise<ListPlansResponse>;
    selectPlan: (request?: Readonly<SelectPlanRequest>) => Promise<Plan>;
    getCurrentPlan: (request?: Readonly<GetCurrentPlanRequest>) => Promise<Plan>;
    deleteCurrentPlan: (request?: Readonly<DeleteCurrentPlanRequest>) => Promise<void>;
    /**
     * Gives information on the currently selected Edge Services subscription
     * plan, resource usage and associated billing information for this calendar
     * month (including whether consumption falls within or exceeds the currently
     * selected subscription plan.).
     *
     * @param request - The request {@link GetBillingRequest}
     * @returns A Promise of GetBillingResponse
     */
    getBilling: (request?: Readonly<GetBillingRequest>) => Promise<GetBillingResponse>;
}
