"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const json = require("../../../helpers/json.cjs");
const marshalling = require("../../../helpers/marshalling.cjs");
require("../../../vendor/base64/index.cjs");
const unmarshalName = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Name' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    key: data.key,
    name: data.name,
    nameId: data.name_id,
    projectId: data.project_id,
    region: data.region,
    status: data.status,
    tags: data.tags,
    updatedAt: marshalling.unmarshalDate(data.updated_at),
    value: data.value
  };
};
const unmarshalPinCIDMeta = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'PinCIDMeta' failed as data isn't a dictionary.`
    );
  }
  return {
    id: data.id
  };
};
const unmarshalPinCID = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'PinCID' failed as data isn't a dictionary.`
    );
  }
  return {
    cid: data.cid,
    meta: data.meta ? unmarshalPinCIDMeta(data.meta) : void 0,
    name: data.name,
    origins: data.origins
  };
};
const unmarshalPinInfo = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'PinInfo' failed as data isn't a dictionary.`
    );
  }
  return {
    id: data.id,
    progress: data.progress,
    size: data.size,
    statusDetails: data.status_details,
    url: data.url
  };
};
const unmarshalPin = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Pin' failed as data isn't a dictionary.`
    );
  }
  return {
    cid: data.cid ? unmarshalPinCID(data.cid) : void 0,
    createdAt: marshalling.unmarshalDate(data.created_at),
    delegates: data.delegates,
    info: data.info ? unmarshalPinInfo(data.info) : void 0,
    pinId: data.pin_id,
    status: data.status
  };
};
const unmarshalVolume = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Volume' failed as data isn't a dictionary.`
    );
  }
  return {
    countPin: data.count_pin,
    createdAt: marshalling.unmarshalDate(data.created_at),
    id: data.id,
    name: data.name,
    projectId: data.project_id,
    region: data.region,
    size: data.size,
    tags: data.tags,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalExportKeyNameResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ExportKeyNameResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    nameId: data.name_id,
    privateKey: data.private_key,
    projectId: data.project_id,
    publicKey: data.public_key,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalListNamesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListNamesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    names: marshalling.unmarshalArrayOfObject(data.names, unmarshalName),
    totalCount: data.total_count
  };
};
const unmarshalListPinsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListPinsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    pins: marshalling.unmarshalArrayOfObject(data.pins, unmarshalPin),
    totalCount: data.total_count
  };
};
const unmarshalListVolumesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListVolumesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    totalCount: data.total_count,
    volumes: marshalling.unmarshalArrayOfObject(data.volumes, unmarshalVolume)
  };
};
const unmarshalReplacePinResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ReplacePinResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    pin: data.pin ? unmarshalPin(data.pin) : void 0
  };
};
const marshalCreatePinByCIDRequest = (request, defaults) => ({
  cid: request.cid,
  name: request.name,
  origins: request.origins,
  volume_id: request.volumeId
});
const marshalCreatePinByURLRequest = (request, defaults) => ({
  name: request.name,
  url: request.url,
  volume_id: request.volumeId
});
const marshalCreateVolumeRequest = (request, defaults) => ({
  name: request.name,
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalIpnsApiCreateNameRequest = (request, defaults) => ({
  name: request.name,
  project_id: request.projectId ?? defaults.defaultProjectId,
  value: request.value
});
const marshalIpnsApiImportKeyNameRequest = (request, defaults) => ({
  name: request.name,
  private_key: request.privateKey,
  project_id: request.projectId ?? defaults.defaultProjectId,
  value: request.value
});
const marshalIpnsApiUpdateNameRequest = (request, defaults) => ({
  name: request.name,
  tags: request.tags,
  value: request.value
});
const marshalReplacePinRequest = (request, defaults) => ({
  cid: request.cid,
  name: request.name,
  origins: request.origins,
  volume_id: request.volumeId
});
const marshalUpdateVolumeRequest = (request, defaults) => ({
  name: request.name,
  tags: request.tags
});
exports.marshalCreatePinByCIDRequest = marshalCreatePinByCIDRequest;
exports.marshalCreatePinByURLRequest = marshalCreatePinByURLRequest;
exports.marshalCreateVolumeRequest = marshalCreateVolumeRequest;
exports.marshalIpnsApiCreateNameRequest = marshalIpnsApiCreateNameRequest;
exports.marshalIpnsApiImportKeyNameRequest = marshalIpnsApiImportKeyNameRequest;
exports.marshalIpnsApiUpdateNameRequest = marshalIpnsApiUpdateNameRequest;
exports.marshalReplacePinRequest = marshalReplacePinRequest;
exports.marshalUpdateVolumeRequest = marshalUpdateVolumeRequest;
exports.unmarshalExportKeyNameResponse = unmarshalExportKeyNameResponse;
exports.unmarshalListNamesResponse = unmarshalListNamesResponse;
exports.unmarshalListPinsResponse = unmarshalListPinsResponse;
exports.unmarshalListVolumesResponse = unmarshalListVolumesResponse;
exports.unmarshalName = unmarshalName;
exports.unmarshalPin = unmarshalPin;
exports.unmarshalReplacePinResponse = unmarshalReplacePinResponse;
exports.unmarshalVolume = unmarshalVolume;
